smartsheet.models package — Smartsheet Python SDK 2.86.1.dev21+gb23b642 documentation

# smartsheet.models package

## Subpackages

- smartsheet.models.enums package
  - Submodules
  - smartsheet.models.enums.access_level module
  - smartsheet.models.enums.attachment_parent_type module
  - smartsheet.models.enums.attachment_sub_type module
  - smartsheet.models.enums.attachment_type module
  - smartsheet.models.enums.automation_action_frequency module
  - smartsheet.models.enums.automation_action_type module
  - smartsheet.models.enums.automation_rule_disabled_reason module
  - smartsheet.models.enums.cell_link_status module
  - smartsheet.models.enums.column_type module
  - smartsheet.models.enums.criteria_target module
  - smartsheet.models.enums.cross_sheet_reference_status module
  - smartsheet.models.enums.currency_code module
  - smartsheet.models.enums.day_descriptors module
  - smartsheet.models.enums.day_ordinal module
  - smartsheet.models.enums.event_action module
  - smartsheet.models.enums.event_obejct_type module
  - smartsheet.models.enums.event_source module
  - smartsheet.models.enums.global_template module
  - smartsheet.models.enums.operator module
  - smartsheet.models.enums.paper_type module
  - smartsheet.models.enums.predecessor_type module
  - smartsheet.models.enums.publish_accessible_by module
  - smartsheet.models.enums.schedule_type module
  - smartsheet.models.enums.share_scope module
  - smartsheet.models.enums.share_type module
  - smartsheet.models.enums.sheet_email_format module
  - smartsheet.models.enums.sheet_filter_operator module
  - smartsheet.models.enums.sheet_filter_type module
  - smartsheet.models.enums.sort_direction module
  - smartsheet.models.enums.symbol module
  - smartsheet.models.enums.system_column_type module
  - smartsheet.models.enums.update_request_status module
  - smartsheet.models.enums.user_status module
  - smartsheet.models.enums.widget_type module
  - Module contents

## Submodules

## smartsheet.models.access_token module

class `smartsheet.models.access_token.` `AccessToken`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet AccessToken data model.

  property `access_token`
  property `expires_at`
  property `expires_in`
  property `refresh_token`
  `to_dict`()
  `to_json`()
  property `token_type`

## smartsheet.models.account module

class `smartsheet.models.account.` `Account`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Account data model.

  property `id_`
  property `name`
  `to_dict`()
  `to_json`()

## smartsheet.models.alternate_email module

class `smartsheet.models.alternate_email.` `AlternateEmail`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet AlternateEmail data model.

  property `confirmed`
  property `email`
  property `id_`
  `to_dict`()
  `to_json`()

## smartsheet.models.attachment module

class `smartsheet.models.attachment.` `Attachment`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Attachment data model.

  property `attachment_sub_type`
  property `attachment_type`
  property `created_at`
  property `created_by`
  property `description`
  property `id_`
  property `mime_type`
  property `name`
  property `parent_id`
  property `parent_type`
  property `size_in_kb`
  `to_dict`()
  `to_json`()
  property `url`
  property `url_expires_in_millis`

## smartsheet.models.auto_number_format module

class `smartsheet.models.auto_number_format.` `AutoNumberFormat`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet AutoNumberFormat data model.

  property `fill`
  property `prefix`
  property `starting_number`
  property `suffix`
  `to_dict`()
  `to_json`()

## smartsheet.models.automation_action module

class `smartsheet.models.automation_action.` `AutomationAction`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet AutomationAction data model.

  property `frequency`
  property `include_all_columns`
  property `include_attachments`
  property `include_discussions`
  property `included_column_ids`
  property `message`
  property `notify_all_shared_users`
  property `recipient_column_ids`
  property `recipients`
  property `subject`
  `to_dict`()
  `to_json`()
  property `type_`

## smartsheet.models.automation_rule module

class `smartsheet.models.automation_rule.` `AutomationRule`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet AutomationRule data model.

  property `action`
  property `created_at`
  property `created_by`
  property `disabled_reason`
  property `disabled_reason_text`
  property `enabled`
  property `id_`
  property `modified_at`
  property `modified_by`
  property `name`
  `to_dict`()
  `to_json`()
  property `user_can_modify`

## smartsheet.models.boolean_object_value module

class `smartsheet.models.boolean_object_value.` `BooleanObjectValue`(value=None, base_obj=None)

  Bases: `smartsheet.models.primitive_object_value.PrimitiveObjectValue`

  Smartsheet BooleanObjectValue data model.

  property `object_type`

## smartsheet.models.bulk_item_failure module

class `smartsheet.models.bulk_item_failure.` `BulkItemFailure`(props=None, dynamic_result_type=None, base_obj=None)

  Bases: `object`

  Smartsheet BulkItemFailure data model.

  property `error`
  property `index`
  property `row_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.bulk_item_result module

class `smartsheet.models.bulk_item_result.` `BulkItemResult`(props=None, dynamic_result_type=None, base_obj=None)

  Bases: `object`

  Smartsheet BulkItemResult data model.

  property `data`

    Simplify difference between Result and IndexResult

  property `failed_items`
  property `message`
  property `result`
  property `result_code`
  `to_dict`()
  `to_json`()
  property `version`

## smartsheet.models.cell module

class `smartsheet.models.cell.` `Cell`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Cell data model.

  property `column_id`
  property `column_type`
  property `conditional_format`
  property `display_value`
  property `format_`
  property `formula`
  property `hyperlink`
  property `image`
  property `link_in_from_cell`
  property `links_out_to_cells`
  property `object_value`
  property `override_validation`
  property `strict`
  `to_dict`()
  `to_json`()
  property `value`

## smartsheet.models.cell_data_item module

class `smartsheet.models.cell_data_item.` `CellDataItem`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CellDataItem data model.

  property `cell`
  property `column_id`
  property `data_source`
  property `label`
  property `label_format`
  property `object_value`
  property `order`
  property `profile_field`
  property `row_id`
  property `sheet_id`
  `to_dict`()
  `to_json`()
  property `value_format`

## smartsheet.models.cell_history module

class `smartsheet.models.cell_history.` `CellHistory`(props=None, base_obj=None)

  Bases: `smartsheet.models.cell.Cell`

  Smartsheet CellHistory data model.

  property `modified_at`
  property `modified_by`
  `to_dict`()
  `to_json`()

## smartsheet.models.cell_link module

class `smartsheet.models.cell_link.` `CellLink`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CellLink data model.

  property `column_id`
  property `row_id`
  property `sheet_id`
  property `sheet_name`
  property `status`
  `to_dict`()
  `to_json`()

## smartsheet.models.cell_link_widget_content module

class `smartsheet.models.cell_link_widget_content.` `CellLinkWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet CellLinkWidgetContent data model.

  property `cell_data`
  property `columns`
  property `hyperlink`
  property `sheet_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.chart_widget_content module

class `smartsheet.models.chart_widget_content.` `ChartWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet ChartWidgetContent data model.

  property `axes`
  property `hyperlink`
  property `included_column_ids`
  property `legend`
  property `report_id`
  property `selection_ranges`
  property `series`
  property `sheet_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.column module

class `smartsheet.models.column.` `Column`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Column data model.

  property `auto_number_format`
  property `contact_options`
  property `description`
  property `format_`
  property `hidden`
  property `id_`
  property `index`
  property `locked`
  property `locked_for_user`
  property `options`
  property `primary`
  property `symbol`
  property `system_column_type`
  property `tags`
  property `title`
  `to_dict`()
  `to_json`()
  property `type_`
  property `validation`
  property `version`
  property `width`

## smartsheet.models.comment module

class `smartsheet.models.comment.` `Comment`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Comment data model.

  property `attachments`
  property `created_at`
  property `created_by`
  property `discussion_id`
  property `id_`
  property `modified_at`
  property `text`
  `to_dict`()
  `to_json`()

## smartsheet.models.contact module

class `smartsheet.models.contact.` `Contact`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Contact data model.

  property `email`
  property `id_`
  property `name`
  `to_dict`()
  `to_json`()

## smartsheet.models.contact_object_value module

class `smartsheet.models.contact_object_value.` `ContactObjectValue`(props=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`, `smartsheet.models.contact.Contact`

  Smartsheet ContactObjectValue data model.

  property `image_id`
  property `ref_index`

## smartsheet.models.container_destination module

class `smartsheet.models.container_destination.` `ContainerDestination`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ContainerDestination data model.

  property `destination_id`
  property `destination_type`
  property `new_name`
  `to_dict`()
  `to_json`()

## smartsheet.models.copy_or_move_row_destination module

class `smartsheet.models.copy_or_move_row_destination.` `CopyOrMoveRowDestination`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CopyOrMoveRowDestination data model.

  property `sheet_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.copy_or_move_row_directive module

class `smartsheet.models.copy_or_move_row_directive.` `CopyOrMoveRowDirective`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CopyOrMoveRowDirective data model.

  property `row_ids`
  property `to`
  `to_dict`()
  `to_json`()

## smartsheet.models.copy_or_move_row_result module

class `smartsheet.models.copy_or_move_row_result.` `CopyOrMoveRowResult`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CopyOrMoveRowResult data model.

  property `destination_sheet_id`
  property `row_mappings`
  `to_dict`()
  `to_json`()

## smartsheet.models.criteria module

class `smartsheet.models.criteria.` `Criteria`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Criteria data model.

  property `column_id`
  property `operator`
  property `target`
  `to_dict`()
  `to_json`()
  property `values`

## smartsheet.models.cross_sheet_reference module

class `smartsheet.models.cross_sheet_reference.` `CrossSheetReference`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet CrossSheetReference data model.

  property `end_column_id`
  property `end_row_id`
  property `id_`
  property `name`
  property `source_sheet_id`
  property `start_column_id`
  property `start_row_id`
  property `status`
  `to_dict`()
  `to_json`()

## smartsheet.models.currency module

class `smartsheet.models.currency.` `Currency`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Currency data model.

  property `code`
  property `symbol`
  `to_dict`()
  `to_json`()

## smartsheet.models.date_object_value module

class `smartsheet.models.date_object_value.` `DateObjectValue`(props=None, object_type=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`

  Smartsheet DateObjectValue data model.

  property `value`

## smartsheet.models.discussion module

class `smartsheet.models.discussion.` `Discussion`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Discussion data model.

  property `access_level`
  property `comment`
  property `comment_attachments`
  property `comment_count`
  property `comments`
  property `created_by`
  property `id_`
  property `last_commented_at`
  property `last_commented_user`
  property `parent_id`
  property `parent_type`
  property `read_only`
  property `title`
  `to_dict`()
  `to_json`()

## smartsheet.models.downloaded_file module

class `smartsheet.models.downloaded_file.` `DownloadedFile`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet DownloadedFile data model.

  property `download_directory`
  property `filename`
  property `message`
  property `resp`
  property `result_code`
  `save_to_file`(chunksize=65536)
  `to_dict`()
  `to_json`()

## smartsheet.models.duration module

class `smartsheet.models.duration.` `Duration`(props=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`

  Smartsheet Duration data model.

  property `days`
  property `elapsed`
  property `hours`
  property `milliseconds`
  property `minutes`
  property `negative`
  property `seconds`
  property `weeks`

## smartsheet.models.email module

class `smartsheet.models.email.` `Email`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Email data model.

  property `cc_me`
  property `message`
  property `send_to`
  property `subject`
  `to_dict`()
  `to_json`()

## smartsheet.models.error module

class `smartsheet.models.error.` `Error`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Error data model.

  property `request_response`
  property `result`
  `to_dict`()
  `to_json`()

## smartsheet.models.error_result module

class `smartsheet.models.error_result.` `ErrorResult`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ErrorResult data model.

  property `code`
  property `error_code`
  property `message`
  property `name`
  property `recommendation`
  property `ref_id`
  property `should_retry`
  property `status_code`
  `to_dict`()
  `to_json`()

## smartsheet.models.event module

class `smartsheet.models.event.` `Event`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Event data model.

  property `access_token_name`
  property `action`
  property `additional_details`
  property `event_id`
  property `event_timestamp`
  property `object_id`
  property `object_type`
  property `request_user_id`
  property `source`
  `to_dict`()
  `to_json`()
  property `user_id`

## smartsheet.models.event_result module

class `smartsheet.models.event_result.` `EventResult`(props=None, dynamic_data_type=None, base_obj=None)

  Bases: `object`

  Smartsheet EventResult data model.

  property `data`
  property `more_available`
  property `next_stream_position`
  `to_dict`()
  `to_json`()

## smartsheet.models.explicit_null module

class `smartsheet.models.explicit_null.` `ExplicitNull`

  Bases: `object`

  `is_explicit_null`()

## smartsheet.models.favorite module

class `smartsheet.models.favorite.` `Favorite`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Favorite data model.

  property `object_id`
  `to_dict`()
  `to_json`()
  property `type_`

## smartsheet.models.folder module

class `smartsheet.models.folder.` `Folder`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Folder data model.

  `create_folder`(folder_obj)
  property `favorite`
  property `folders`
  property `id_`
  property `name`
  property `permalink`
  property `reports`
  property `sheets`
  property `sights`
  property `templates`
  `to_dict`()
  `to_json`()

## smartsheet.models.font_family module

class `smartsheet.models.font_family.` `FontFamily`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet FontFamily data model.

  property `name`
  `to_dict`()
  `to_json`()
  property `traits`

## smartsheet.models.format_details module

class `smartsheet.models.format_details.` `FormatDetails`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet FormatDetails data model.

  property `paper_size`
  `to_dict`()
  `to_json`()

## smartsheet.models.format_tables module

class `smartsheet.models.format_tables.` `FormatTables`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet FormatTables data model.

  property `bold`
  property `color`
  property `currency`
  property `date_format`
  property `decimal_count`
  property `defaults`
  property `font_family`
  property `font_size`
  property `horizontal_align`
  property `italic`
  property `number_format`
  property `strikethrough`
  property `text_wrap`
  property `thousands_separator`
  `to_dict`()
  `to_json`()
  property `underline`
  property `vertical_align`

## smartsheet.models.group module

class `smartsheet.models.group.` `Group`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Group data model.

  property `created_at`
  property `description`
  property `id_`
  property `members`
  property `modified_at`
  property `name`
  property `owner`
  property `owner_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.group_member module

class `smartsheet.models.group_member.` `GroupMember`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet GroupMember data model.

  property `email`
  property `first_name`
  property `id_`
  property `last_name`
  property `name`
  `to_dict`()
  `to_json`()

## smartsheet.models.home module

class `smartsheet.models.home.` `Home`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Home data model.

  property `folders`
  property `reports`
  property `sheets`
  property `sights`
  property `templates`
  `to_dict`()
  `to_json`()
  property `workspaces`

## smartsheet.models.hyperlink module

class `smartsheet.models.hyperlink.` `Hyperlink`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Hyperlink data model.

  property `report_id`
  property `sheet_id`
  property `sight_id`
  `to_dict`()
  `to_json`()
  property `url`

## smartsheet.models.image module

class `smartsheet.models.image.` `Image`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Image data model.

  property `alt_text`
  property `height`
  property `id_`
  property `image_id`
  `to_dict`()
  `to_json`()
  property `width`

## smartsheet.models.image_url module

class `smartsheet.models.image_url.` `ImageUrl`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ImageUrl data model.

  property `error`
  property `height`
  property `image_id`
  `to_dict`()
  `to_json`()
  property `url`
  property `width`

## smartsheet.models.image_url_map module

class `smartsheet.models.image_url_map.` `ImageUrlMap`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ImageUrlMap data model.

  property `image_urls`
  `to_dict`()
  `to_json`()
  property `url_expires_in_millis`

## smartsheet.models.image_widget_content module

class `smartsheet.models.image_widget_content.` `ImageWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet ImageWidgetContent data model.

  property `file_name`
  property `format_`
  property `height`
  property `hyperlink`
  property `private_id`
  `to_dict`()
  `to_json`()
  property `width`

## smartsheet.models.index_result module

class `smartsheet.models.index_result.` `IndexResult`(props=None, dynamic_data_type=None, base_obj=None)

  Bases: `object`

  Smartsheet IndexResult data model.

  property `data`
  property `page_number`
  property `page_size`
  property `result`

    Simplify difference between Result and IndexResult

  `to_dict`()
  `to_json`()
  property `total_count`
  property `total_pages`

## smartsheet.models.json_object module

class `smartsheet.models.json_object.` `JSONObject`(payload=None, base_obj=None)

  Bases: `object`

  Smartsheet JSONObject data model.

  property `data`
  `serialize`()
  `to_dict`()
  `to_json`()

## smartsheet.models.multi_contact_object_value module

class `smartsheet.models.multi_contact_object_value.` `MultiContactObjectValue`(props=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`

  Smartsheet MultiContactObjectValue data model.

  property `values`

## smartsheet.models.multi_picklist_object_value module

class `smartsheet.models.multi_picklist_object_value.` `MultiPicklistObjectValue`(props=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`

  Smartsheet MultiPicklistObjectValue data model.

  property `values`

## smartsheet.models.multi_row_email module

class `smartsheet.models.multi_row_email.` `MultiRowEmail`(props=None, base_obj=None)

  Bases: `smartsheet.models.row_email.RowEmail`

  Smartsheet MultiRowEmail data model.

  property `row_ids`
  `to_dict`()
  `to_json`()

## smartsheet.models.number_object_value module

class `smartsheet.models.number_object_value.` `NumberObjectValue`(value=None, base_obj=None)

  Bases: `smartsheet.models.primitive_object_value.PrimitiveObjectValue`

  Smartsheet NumberObjectValue data model.

  property `object_type`

## smartsheet.models.o_auth_error module

class `smartsheet.models.o_auth_error.` `OAuthError`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet OAuthError data model.

  property `error`
  property `error_code`
  property `error_description`
  `to_dict`()
  `to_json`()

## smartsheet.models.object_value module

class `smartsheet.models.object_value.` `ObjectValue`(object_type=None, base_obj=None)

  Bases: `object`

  Smartsheet ObjectValue data model.

  property `object_type`
  `serialize`()
  `to_dict`()
  `to_json`()

`smartsheet.models.object_value.` `enum_object_value_type`(object_type=None)

## smartsheet.models.predecessor module

class `smartsheet.models.predecessor.` `Predecessor`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Predecessor data model.

  property `in_critical_path`
  property `invalid`
  property `lag`
  property `row_id`
  property `row_number`
  `to_dict`()
  `to_json`()
  property `type`

## smartsheet.models.predecessor_list module

class `smartsheet.models.predecessor_list.` `PredecessorList`(props=None, base_obj=None)

  Bases: `smartsheet.models.object_value.ObjectValue`

  Smartsheet PredecessorList data model.

  property `predecessors`

## smartsheet.models.primitive_object_value module

class `smartsheet.models.primitive_object_value.` `PrimitiveObjectValue`(value=None, base_obj=None)

  Bases: `object`

  Smartsheet PrimitiveObjectValue data model.

  `serialize`()
  `to_dict`()
  `to_json`()
  property `value`

## smartsheet.models.profile_image module

class `smartsheet.models.profile_image.` `ProfileImage`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Profile Image data model.

  property `height`
  property `image_id`
  `to_dict`()
  `to_json`()
  property `width`

## smartsheet.models.project_settings module

class `smartsheet.models.project_settings.` `ProjectSettings`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ProjectSettings data model.

  property `length_of_day`
  property `non_working_days`
  `to_dict`()
  `to_json`()
  property `working_days`

## smartsheet.models.recipient module

class `smartsheet.models.recipient.` `Recipient`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Recipient data model.

  property `email`
  property `group_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.report module

class `smartsheet.models.report.` `Report`(props=None, base_obj=None)

  Bases: `smartsheet.models.sheet.Sheet`

  Smartsheet Report data model.

  property `columns`
  property `rows`
  property `scope`
  property `source_sheets`
  `to_dict`()
  `to_json`()

## smartsheet.models.report_cell module

class `smartsheet.models.report_cell.` `ReportCell`(props=None, base_obj=None)

  Bases: `smartsheet.models.cell.Cell`

  Smartsheet ReportCell data model.

  `to_dict`()
  `to_json`()
  property `virtual_column_id`

## smartsheet.models.report_column module

class `smartsheet.models.report_column.` `ReportColumn`(props=None, base_obj=None)

  Bases: `smartsheet.models.column.Column`

  Smartsheet ReportColumn data model.

  property `sheet_name_column`
  `to_dict`()
  `to_json`()
  property `virtual_id`

## smartsheet.models.report_publish module

class `smartsheet.models.report_publish.` `ReportPublish`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ReportPublish data model.

  property `read_only_full_accessible_by`
  property `read_only_full_default_view`
  property `read_only_full_enabled`
  property `read_only_full_show_toolbar`
  property `read_only_full_url`
  `to_dict`()
  `to_json`()

## smartsheet.models.report_row module

class `smartsheet.models.report_row.` `ReportRow`(props=None, base_obj=None)

  Bases: `smartsheet.models.row.Row`

  Smartsheet ReportRow data model.

  property `cells`
  property `sheet_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.report_widget_content module

class `smartsheet.models.report_widget_content.` `ReportWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet ReportWidgetContent data model.

  property `html_content`
  property `hyperlink`
  property `report_id`
  `to_dict`()
  `to_json`()

## smartsheet.models.result module

class `smartsheet.models.result.` `Result`(props=None, dynamic_result_type=None, base_obj=None)

  Bases: `object`

  Smartsheet Result data model.

  property `data`

    Simplify difference between Result and IndexResult

  property `message`
  property `result`
  property `result_code`
  `to_dict`()
  `to_json`()
  property `version`

## smartsheet.models.row module

class `smartsheet.models.row.` `Row`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Row data model.

  property `above`
  property `access_level`
  property `attachments`
  property `cells`
  property `columns`
  property `conditional_format`
  property `created_at`
  property `created_by`
  property `discussions`
  property `expanded`
  property `filtered_out`
  property `format_`
  `get_column`(column_id)
  property `id_`
  property `in_critical_path`
  property `indent`
  property `locked`
  property `locked_for_user`
  property `modified_at`
  property `modified_by`
  property `outdent`
  property `parent_id`
  property `permalink`
  property `row_number`
  `set_column`(column_id, replacement_cell)
  property `sheet_id`
  property `sibling_id`
  property `to_bottom`
  `to_dict`()
  `to_json`()
  property `to_top`
  property `version`

## smartsheet.models.row_email module

class `smartsheet.models.row_email.` `RowEmail`(props=None, base_obj=None)

  Bases: `smartsheet.models.email.Email`

  Smartsheet RowEmail data model.

  property `column_ids`
  property `include_attachments`
  property `include_discussions`
  property `layout`
  `to_dict`()
  `to_json`()

## smartsheet.models.row_mapping module

class `smartsheet.models.row_mapping.` `RowMapping`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet RowMapping data model.

  property `from_`
  property `to`
  `to_dict`()
  `to_json`()

## smartsheet.models.schedule module

class `smartsheet.models.schedule.` `Schedule`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Schedule data model.

  property `day_descriptors`
  property `day_of_month`
  property `day_ordinal`
  property `end_at`
  property `last_sent_at`
  property `next_send_at`
  property `repeat_every`
  property `start_at`
  `to_dict`()
  `to_json`()
  property `type_`

## smartsheet.models.scope module

class `smartsheet.models.scope.` `Scope`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Scope data model.

  property `sheets`
  `to_dict`()
  `to_json`()
  property `workspaces`

## smartsheet.models.search_result module

class `smartsheet.models.search_result.` `SearchResult`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SearchResult data model.

  property `results`
  `to_dict`()
  `to_json`()
  property `total_count`

## smartsheet.models.search_result_item module

class `smartsheet.models.search_result_item.` `SearchResultItem`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SearchResultItem data model.

  property `context_data`
  property `favorite`
  property `object_id`
  property `object_type`
  property `parent_object_favorite`
  property `parent_object_id`
  property `parent_object_name`
  property `parent_object_type`
  property `text`
  `to_dict`()
  `to_json`()

## smartsheet.models.selection_range module

class `smartsheet.models.selection_range.` `SelectionRange`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SelectionRange data model.

  property `source_column_id1`
  property `source_column_id2`
  property `source_row_id1`
  property `source_row_id2`
  `to_dict`()
  `to_json`()

## smartsheet.models.sent_update_request module

class `smartsheet.models.sent_update_request.` `SentUpdateRequest`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SentUpdateRequest data model.

  property `column_ids`
  property `id_`
  property `include_attachments`
  property `include_discussions`
  property `message`
  property `row_ids`
  property `sent_at`
  property `sent_by`
  property `sent_to`
  property `status`
  property `subject`
  `to_dict`()
  `to_json`()
  property `update_request_id`

## smartsheet.models.server_info module

class `smartsheet.models.server_info.` `ServerInfo`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ServerInfo data model.

  property `formats`
  property `supported_locales`
  `to_dict`()
  `to_json`()

## smartsheet.models.share module

class `smartsheet.models.share.` `Share`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Share data model.

  property `access_level`
  property `cc_me`
  property `created_at`
  property `email`
  property `group_id`
  property `id_`
  property `message`
  property `modified_at`
  property `name`
  property `scope`
  property `subject`
  `to_dict`()
  `to_json`()
  property `type_`
  property `user_id`

## smartsheet.models.sheet module

class `smartsheet.models.sheet.` `Sheet`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Sheet data model.

  property `access_level`
  `add_columns`(list_of_columns)
  `add_rows`(list_of_rows)
  `attach_url`(attachment_obj)
  property `attachments`
  property `columns`
  property `contact_references`
  `create_discussion`(title, comment, _file=None)
  property `created_at`
  property `cross_sheet_references`
  `delete_column`(column_id)
  `delete_rows`(object_ids, ignore_rows_not_found=False)
  `delete_share`(share_id)
  property `dependencies_enabled`
  property `discussions`
  property `effective_attachment_options`
  property `favorite`
  property `filters`
  property `from_id`
  property `gantt_enabled`
  `get_all_discussions`(include=None, page_size=100, page=1, include_all=False)
  `get_column`(column_id, include=None)
  `get_column_by_title`(title)
  `get_columns`(include=None, page_size=100, page=1, include_all=False)
  `get_publish_status`()
  `get_row`(row_id, include=None, exclude=None)
  `get_share`(share_id)
  `get_version`()
  property `has_summary_fields`
  property `id_`
  `list_shares`(page_size=100, page=1, include_all=False)
  property `modified_at`
  property `name`
  property `owner`
  property `owner_id`
  property `permalink`
  property `project_settings`
  property `read_only`
  property `resource_management_enabled`
  property `rows`
  `set_publish_status`(sheet_publish_obj)
  `share`(share_obj, send_email=False)
  `shares`(page_size=100, page=1, include_all=False)
  property `show_parent_rows_for_filters`
  property `source`
  property `summary`
  `to_dict`()
  `to_json`()
  property `total_row_count`
  `update_name`(new_name)
  `update_share`(share_id, share_obj)
  property `user_permissions`
  property `user_settings`
  property `version`
  property `workspace`

## smartsheet.models.sheet_email module

class `smartsheet.models.sheet_email.` `SheetEmail`(props=None, base_obj=None)

  Bases: `smartsheet.models.email.Email`

  Smartsheet SheetEmail data model.

  property `format_`
  property `format_details`
  `to_dict`()
  `to_json`()

## smartsheet.models.sheet_filter module

class `smartsheet.models.sheet_filter.` `SheetFilter`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetFilter data model.

  property `filter_type`
  property `id_`
  property `name`
  property `query`
  `to_dict`()
  `to_json`()
  property `version`

## smartsheet.models.sheet_filter_details module

class `smartsheet.models.sheet_filter_details.` `SheetFilterDetails`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetFilterDetails data model.

  property `criteria`
  property `include_parent`
  property `operator`
  `to_dict`()
  `to_json`()

## smartsheet.models.sheet_publish module

class `smartsheet.models.sheet_publish.` `SheetPublish`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetPublish data model.

  property `ical_enabled`
  property `ical_url`
  property `read_only_full_accessible_by`
  property `read_only_full_default_view`
  property `read_only_full_enabled`
  property `read_only_full_show_toolbar`
  property `read_only_full_url`
  property `read_only_lite_enabled`
  property `read_only_lite_ssl_url`
  property `read_only_lite_url`
  property `read_write_accessible_by`
  property `read_write_default_view`
  property `read_write_enabled`
  property `read_write_show_toolbar`
  property `read_write_url`
  `to_dict`()
  `to_json`()

## smartsheet.models.sheet_summary module

class `smartsheet.models.sheet_summary.` `SheetSummary`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetSummary data model.

  property `fields`
  `to_dict`()
  `to_json`()

## smartsheet.models.sheet_user_permissions module

class `smartsheet.models.sheet_user_permissions.` `SheetUserPermissions`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetUserPermissions data model.

  property `summary_permissions`
  `to_dict`()
  `to_json`()

## smartsheet.models.sheet_user_settings module

class `smartsheet.models.sheet_user_settings.` `SheetUserSettings`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SheetUserSettings data model.

  property `applied_sheet_filter_id`
  property `critical_path_enabled`
  property `display_summary_tasks`
  `to_dict`()
  `to_json`()

## smartsheet.models.shortcut_data_item module

class `smartsheet.models.shortcut_data_item.` `ShortcutDataItem`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet ShortcutDataItem data model.

  property `attachment_type`
  property `hyperlink`
  property `label`
  property `label_format`
  property `mime_type`
  property `order`
  `to_dict`()
  `to_json`()

## smartsheet.models.shortcut_widget_content module

class `smartsheet.models.shortcut_widget_content.` `ShortcutWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet ShortcutWidgetContent data model.

  property `shortcut_data`
  `to_dict`()
  `to_json`()

## smartsheet.models.sight module

class `smartsheet.models.sight.` `Sight`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Sight data model.

  property `access_level`
  property `background_color`
  property `column_count`
  property `created_at`
  property `favorite`
  property `id_`
  property `modified_at`
  property `name`
  property `permalink`
  property `source`
  `to_dict`()
  `to_json`()
  property `widgets`
  property `workspace`

## smartsheet.models.sight_publish module

class `smartsheet.models.sight_publish.` `SightPublish`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SightPublish data model.

  property `read_only_full_accessible_by`
  property `read_only_full_enabled`
  property `read_only_full_url`
  `to_dict`()
  `to_json`()

## smartsheet.models.sort_criterion module

class `smartsheet.models.sort_criterion.` `SortCriterion`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SortCriterion data model.

  property `column_id`
  property `direction`
  `to_dict`()
  `to_json`()

## smartsheet.models.sort_specifier module

class `smartsheet.models.sort_specifier.` `SortSpecifier`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SortSpecifier data model.

  property `sort_criteria`
  `to_dict`()
  `to_json`()

## smartsheet.models.source module

class `smartsheet.models.source.` `Source`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Source data model.

  property `id_`
  `to_dict`()
  `to_json`()
  property `type_`

## smartsheet.models.string_object_value module

class `smartsheet.models.string_object_value.` `StringObjectValue`(value=None, base_obj=None)

  Bases: `smartsheet.models.primitive_object_value.PrimitiveObjectValue`

  Smartsheet StringObjectValue data model.

  property `object_type`

## smartsheet.models.summary_field module

class `smartsheet.models.summary_field.` `SummaryField`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet SummaryField data model.

  property `contact_options`
  property `created_at`
  property `created_by`
  property `display_value`
  property `format_`
  property `formula`
  property `hyperlink`
  property `id_`
  property `image`
  property `index`
  property `locked`
  property `locked_for_user`
  property `modified_at`
  property `modified_by`
  property `object_value`
  property `options`
  property `symbol`
  property `title`
  `to_dict`()
  `to_json`()
  property `type_`
  property `validation`

## smartsheet.models.template module

class `smartsheet.models.template.` `Template`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Template data model.

  property `access_level`
  property `blank`
  property `categories`
  property `description`
  property `global_template`
  property `id_`
  property `image`
  property `large_image`
  property `locale`
  property `name`
  property `tags`
  `to_dict`()
  `to_json`()
  property `type`

## smartsheet.models.title_rich_text_widget_content module

class `smartsheet.models.title_rich_text_widget_content.` `TitleRichTextWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet TitleRichTextWidgetContent data model.

  property `background_color`
  property `html_content`
  `to_dict`()
  `to_json`()

## smartsheet.models.update_request module

class `smartsheet.models.update_request.` `UpdateRequest`(props=None, base_obj=None)

  Bases: `smartsheet.models.multi_row_email.MultiRowEmail`

  Smartsheet UpdateRequest data model.

  property `created_at`
  property `id_`
  property `modified_at`
  property `schedule`
  property `sent_by`
  `to_dict`()
  `to_json`()

## smartsheet.models.user module

class `smartsheet.models.user.` `User`(props=None, base_obj=None)

  Bases: `smartsheet.models.user_model.UserModel`

  Smartsheet User data model.

  property `name`
  `to_dict`()
  `to_json`()

## smartsheet.models.user_model module

class `smartsheet.models.user_model.` `UserModel`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet UserModel data model.

  property `admin`
  property `alternate_emails`
  property `company`
  property `custom_welcome_screen_viewed`
  property `department`
  property `email`
  property `first_name`
  property `group_admin`
  property `id_`
  property `last_login`
  property `last_name`
  property `licensed_sheet_creator`
  property `mobile_phone`
  property `profile_image`
  property `resource_viewer`
  property `role`
  property `sheet_count`
  property `status`
  property `title`
  `to_dict`()
  `to_json`()
  property `work_phone`

## smartsheet.models.user_profile module

class `smartsheet.models.user_profile.` `UserProfile`(props=None, base_obj=None)

  Bases: `smartsheet.models.user_model.UserModel`

  Smartsheet UserProfile data model.

  property `account`
  property `groups`
  property `locale`
  property `time_zone`
  `to_dict`()
  `to_json`()

## smartsheet.models.version module

class `smartsheet.models.version.` `Version`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Version data model.

  `to_dict`()
  `to_json`()
  property `version`

## smartsheet.models.web_content_widget_content module

class `smartsheet.models.web_content_widget_content.` `WebContentWidgetContent`(props=None, base_obj=None)

  Bases: `smartsheet.models.widget_content.WidgetContent`

  Smartsheet WebContentWidgetContent data model.

  `to_dict`()
  `to_json`()
  property `url`

## smartsheet.models.webhook module

class `smartsheet.models.webhook.` `Webhook`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Webhook data model.

  property `api_client_id`
  property `api_client_name`
  property `callback_url`
  property `created_at`
  property `disabled_details`
  property `enabled`
  property `events`
  property `id_`
  property `modified_at`
  property `name`
  property `scope`
  property `scope_object_id`
  property `shared_secret`
  property `stats`
  property `status`
  property `subscope`
  `to_dict`()
  `to_json`()
  property `version`

## smartsheet.models.webhook_secret module

class `smartsheet.models.webhook_secret.` `WebhookSecret`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet WebhookSecret data model.

  property `shared_secret`
  `to_dict`()
  `to_json`()

## smartsheet.models.webhook_stats module

class `smartsheet.models.webhook_stats.` `WebhookStats`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet WebhookStats data model.

  property `last_callback_attempt`
  property `last_callback_attempt_retry_count`
  property `last_successful_callback`
  `to_dict`()
  `to_json`()

## smartsheet.models.webhook_subscope module

class `smartsheet.models.webhook_subscope.` `WebhookSubscope`(props=None)

  Bases: `object`

  Represents the webhook subscope object.

  property `column_ids`
  `to_dict`()
  `to_json`()

## smartsheet.models.widget module

class `smartsheet.models.widget.` `Widget`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Widget data model.

  property `contents`
  property `error`
  property `height`
  property `id_`
  property `show_title`
  property `show_title_icon`
  property `title`
  property `title_format`
  `to_dict`()
  `to_json`()
  property `type`
  property `version`
  property `width`
  property `x_position`
  property `y_position`

## smartsheet.models.widget_content module

class `smartsheet.models.widget_content.` `WidgetContent`(widget_type=None, base_obj=None)

  Bases: `object`

  Smartsheet WidgetContent data model.

  `to_dict`()
  `to_json`()
  property `widget_type`

## smartsheet.models.widget_hyperlink module

class `smartsheet.models.widget_hyperlink.` `WidgetHyperlink`(props=None, base_obj=None)

  Bases: `smartsheet.models.hyperlink.Hyperlink`

  Smartsheet WidgetHyperlink data model.

  property `folder_id`
  property `interaction_type`
  `to_dict`()
  `to_json`()
  property `workspace_id`

## smartsheet.models.workspace module

class `smartsheet.models.workspace.` `Workspace`(props=None, base_obj=None)

  Bases: `object`

  Smartsheet Workspace data model.

  property `access_level`
  property `favorite`
  property `folders`
  property `id_`
  property `name`
  property `permalink`
  property `reports`
  property `sheets`
  property `sights`
  property `templates`
  `to_dict`()
  `to_json`()

## Module contents